==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPAMConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IPAMConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent<A>{
  public IPAMConfigFluentImpl() {
  }
  public IPAMConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.IPAMConfig instance) {
    this.withStaticIPAMConfig(instance.getStaticIPAMConfig()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder staticIPAMConfig;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildStaticIPAMConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig getStaticIPAMConfig() {
    return this.staticIPAMConfig!=null?this.staticIPAMConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig buildStaticIPAMConfig() {
    return this.staticIPAMConfig!=null?this.staticIPAMConfig.build():null;
  }
  public A withStaticIPAMConfig(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig staticIPAMConfig) {
    _visitables.get("staticIPAMConfig").remove(this.staticIPAMConfig);
    if (staticIPAMConfig!=null){ this.staticIPAMConfig= new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(staticIPAMConfig); _visitables.get("staticIPAMConfig").add(this.staticIPAMConfig);} return (A) this;
  }
  public java.lang.Boolean hasStaticIPAMConfig() {
    return this.staticIPAMConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> withNewStaticIPAMConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluentImpl.StaticIPAMConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> withNewStaticIPAMConfigLike(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluentImpl.StaticIPAMConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editStaticIPAMConfig() {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editOrNewStaticIPAMConfig() {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig() != null ? getStaticIPAMConfig(): new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editOrNewStaticIPAMConfigLike(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig() != null ? getStaticIPAMConfig(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPAMConfigFluentImpl that = (IPAMConfigFluentImpl) o;
    if (staticIPAMConfig != null ? !staticIPAMConfig.equals(that.staticIPAMConfig) :that.staticIPAMConfig != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(staticIPAMConfig,  type,  additionalProperties,  super.hashCode());
  }
  public class StaticIPAMConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StaticIPAMConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(this, item);
    }
    StaticIPAMConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder builder;
    public N and() {
      return (N) IPAMConfigFluentImpl.this.withStaticIPAMConfig(builder.build());
    }
    public N endStaticIPAMConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IPAMConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IPAMConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent<A>{
  public IPAMConfigFluentImpl() {
  }
  public IPAMConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.IPAMConfig instance) {
    this.withStaticIPAMConfig(instance.getStaticIPAMConfig()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder staticIPAMConfig;
  private java.lang.String type;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildStaticIPAMConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig getStaticIPAMConfig() {
    return this.staticIPAMConfig!=null?this.staticIPAMConfig.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig buildStaticIPAMConfig() {
    return this.staticIPAMConfig!=null?this.staticIPAMConfig.build():null;
  }
  public A withStaticIPAMConfig(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig staticIPAMConfig) {
    _visitables.get("staticIPAMConfig").remove(this.staticIPAMConfig);
    if (staticIPAMConfig!=null){ this.staticIPAMConfig= new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(staticIPAMConfig); _visitables.get("staticIPAMConfig").add(this.staticIPAMConfig);} return (A) this;
  }
  public java.lang.Boolean hasStaticIPAMConfig() {
    return this.staticIPAMConfig != null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> withNewStaticIPAMConfig() {
    return new io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluentImpl.StaticIPAMConfigNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> withNewStaticIPAMConfigLike(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
    return new io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluentImpl.StaticIPAMConfigNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editStaticIPAMConfig() {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig());
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editOrNewStaticIPAMConfig() {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig() != null ? getStaticIPAMConfig(): new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<A> editOrNewStaticIPAMConfigLike(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
    return withNewStaticIPAMConfigLike(getStaticIPAMConfig() != null ? getStaticIPAMConfig(): item);
  }
  public java.lang.String getType() {
    return this.type;
  }
  public A withType(java.lang.String type) {
    this.type=type; return (A) this;
  }
  public java.lang.Boolean hasType() {
    return this.type != null;
  }
  
  /**
   * Method is deprecated. use withType instead.
   */
  @java.lang.Deprecated
  public A withNewType(java.lang.String arg0) {
    return (A)withType(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPAMConfigFluentImpl that = (IPAMConfigFluentImpl) o;
    if (staticIPAMConfig != null ? !staticIPAMConfig.equals(that.staticIPAMConfig) :that.staticIPAMConfig != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(staticIPAMConfig,  type,  additionalProperties,  super.hashCode());
  }
  public class StaticIPAMConfigNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigFluentImpl<io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IPAMConfigFluent.StaticIPAMConfigNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    StaticIPAMConfigNestedImpl(io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfig item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(this, item);
    }
    StaticIPAMConfigNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.StaticIPAMConfigBuilder builder;
    public N and() {
      return (N) IPAMConfigFluentImpl.this.withStaticIPAMConfig(builder.build());
    }
    public N endStaticIPAMConfig() {
      return and();
    }
    
  }
  
}
